==> miria-monitor-api-0.0.3-20180822.085031-9-sources.jar: cn/com/duiba/miria/monitor/api/entity/AppTriggerTemplate.java <==
package cn.com.duiba.miria.monitor.api.entity;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

@Table(name = "tb_app_trigger_template")
public class AppTriggerTemplate {
    /**
     * 主键id
     */
    @Id
    private Long id;

    /**
     * 模板id,tb_trigger_template.id
     */
    @Column(name = "template_id")
    private Long templateId;

    /**
     * 应用,来源：app.id
     */
    @Column(name = "app_id")
    private Long appId;

    /**
     * 创建时间
     */
    @Column(name = "gmt_create")
    private Date gmtCreate;

    /**
     * 修改时间
     */
    @Column(name = "gmt_modified")
    private Date gmtModified;

    /**
     * 获取主键id
     *
     * @return id - 主键id
     */
    public Long getId() {
        return id;
    }

    /**
     * 设置主键id
     *
     * @param id 主键id
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * 获取模板id,tb_trigger_template.id
     *
     * @return template_id - 模板id,tb_trigger_template.id
     */
    public Long getTemplateId() {
        return templateId;
    }

    /**
     * 设置模板id,tb_trigger_template.id
     *
     * @param templateId 模板id,tb_trigger_template.id
     */
    public void setTemplateId(Long templateId) {
        this.templateId = templateId;
    }

    /**
     * 获取应用,来源：app.id
     *
     * @return app_id - 应用,来源：app.id
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * 设置应用,来源：app.id
     *
     * @param appId 应用,来源：app.id
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    /**
     * 获取创建时间
     *
     * @return gmt_create - 创建时间
     */
    public Date getGmtCreate() {
        return gmtCreate;
    }

    /**
     * 设置创建时间
     *
     * @param gmtCreate 创建时间
     */
    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    /**
     * 获取修改时间
     *
     * @return gmt_modified - 修改时间
     */
    public Date getGmtModified() {
        return gmtModified;
    }

    /**
     * 设置修改时间
     *
     * @param gmtModified 修改时间
     */
    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> miria-monitor-api-1.0.12-sources.jar: cn/com/duiba/miria/monitor/api/entity/AppTriggerTemplate.java <==
package cn.com.duiba.miria.monitor.api.entity;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

@Table(name = "tb_app_trigger_template")
public class AppTriggerTemplate implements Serializable {
    /**
     * 主键id
     */
    @Id
    private Long id;

    /**
     * 模板id,tb_trigger_template.id
     */
    @Column(name = "template_id")
    private Long templateId;

    /**
     * 应用,来源：app.id
     */
    @Column(name = "app_id")
    private Long appId;

    /**
     * 创建时间
     */
    @Column(name = "gmt_create")
    private Date gmtCreate;

    /**
     * 修改时间
     */
    @Column(name = "gmt_modified")
    private Date gmtModified;

    /**
     * 获取主键id
     *
     * @return id - 主键id
     */
    public Long getId() {
        return id;
    }

    /**
     * 设置主键id
     *
     * @param id 主键id
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * 获取模板id,tb_trigger_template.id
     *
     * @return template_id - 模板id,tb_trigger_template.id
     */
    public Long getTemplateId() {
        return templateId;
    }

    /**
     * 设置模板id,tb_trigger_template.id
     *
     * @param templateId 模板id,tb_trigger_template.id
     */
    public void setTemplateId(Long templateId) {
        this.templateId = templateId;
    }

    /**
     * 获取应用,来源：app.id
     *
     * @return app_id - 应用,来源：app.id
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * 设置应用,来源：app.id
     *
     * @param appId 应用,来源：app.id
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    /**
     * 获取创建时间
     *
     * @return gmt_create - 创建时间
     */
    public Date getGmtCreate() {
        return gmtCreate;
    }

    /**
     * 设置创建时间
     *
     * @param gmtCreate 创建时间
     */
    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    /**
     * 获取修改时间
     *
     * @return gmt_modified - 修改时间
     */
    public Date getGmtModified() {
        return gmtModified;
    }

    /**
     * 设置修改时间
     *
     * @param gmtModified 修改时间
     */
    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
